@@ -1,6 +1,7 @@
-from typing import Any, Type
+from typing import Any, Dict, List, Type, Union
 
 from asyncpg import Connection, Record, connect
+from pypika.queries import QueryBuilder
 
 from p3orm.types import Model
 from p3orm.utils import record_to_kwargs
@@ -19,7 +20,7 @@ class _Porm:
         database: str = None,
         host: str = None,
         port: int = None,
-        **asyncpg_kwargs: dict[str, Any]
+        **asyncpg_kwargs: Dict[str, Any]
     ):
         self.connection = await connect(
             dsn=dsn,
@@ -34,7 +35,11 @@ class _Porm:
     async def disconnect(self):
         await self.connection.close()
 
-    async def fetch_one(self, query: str, table: Type[Model]) -> Model:
+    async def fetch_one(self, query: Union[str, QueryBuilder], table: Type[Model]) -> Model:
+
+        if isinstance(query, QueryBuilder):
+            query = query.get_sql()
+
         resp: Record = await self.connection.fetchrow(query)
 
         if resp is None:
@@ -42,7 +47,11 @@ class _Porm:
 
         return table(**record_to_kwargs(resp))
 
-    async def fetch_many(self, query: str, table: Type[Model]) -> list[Model]:
+    async def fetch_many(self, query: Union[str, QueryBuilder], table: Type[Model]) -> List[Model]:
+
+        if isinstance(query, QueryBuilder):
+            query = query.get_sql()
+
         resp = await self.connection.fetch(query)
         return [table(**record_to_kwargs(row)) for row in resp]
 
